#' @keywords internal
#' @name biometryassist
#' @aliases biometryassist-package
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL

utils::globalVariables(c("PredictedValue", "low", "predicted.value",
                         "up", "x", "y", "z", "color_blind","xmin",
                         "xmax", "ymin", "ymax", "Row", "treatments",
                         "stdres", "groups", ".data"))
